adadmire package
================

.. automodule:: adadmire
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

adadmire.apgpy module
---------------------

.. automodule:: adadmire.apgpy
   :members:
   :undoc-members:
   :show-inheritance:

adadmire.main module
--------------------

.. automodule:: adadmire.main
   :members:
   :undoc-members:
   :show-inheritance:

adadmire.mgm module
-------------------

.. automodule:: adadmire.mgm
   :members:
   :undoc-members:
   :show-inheritance:
